@@ -21,7 +21,9 @@ import sys
 import warnings
 from datetime import datetime
 from enum import Enum
-from typing import Iterable, Optional, Set
+from typing import Any, Iterable, Optional, Tuple, TypeVar
+
+from sortedcontainers import SortedSet
 
 from ..exception.model import (
     InvalidLocaleTypeException,
@@ -57,7 +59,44 @@ def sha1sum(filename: str) -> str:
     return h.hexdigest()
 
 
-class DataFlow(Enum):
+_T = TypeVar('_T')
+
+
+class ComparableTuple(Tuple[Optional[_T], ...]):
+    """
+    Allows comparison of tuples, allowing for None values.
+    """
+
+    def __lt__(self, other: Any) -> bool:
+        for s, o in zip(self, other):
+            if s == o:
+                continue
+            if s is None:
+                return False
+            if o is None:
+                return True
+            if s < o:
+                return True
+            if s > o:
+                return False
+        return False
+
+    def __gt__(self, other: Any) -> bool:
+        for s, o in zip(self, other):
+            if s == o:
+                continue
+            if s is None:
+                return True
+            if o is None:
+                return False
+            if s < o:
+                return False
+            if s > o:
+                return True
+        return False
+
+
+class DataFlow(str, Enum):
     """
     This is our internal representation of the dataFlowType simple type within the CycloneDX standard.
 
@@ -132,7 +171,7 @@ class DataClassification:
         return f'<DataClassification flow={self.flow}>'
 
 
-class Encoding(Enum):
+class Encoding(str, Enum):
     """
     This is our internal representation of the encoding simple type within the CycloneDX standard.
 
@@ -208,6 +247,12 @@ class AttachedText:
             return hash(other) == hash(self)
         return False
 
+    def __lt__(self, other: Any) -> bool:
+        if isinstance(other, AttachedText):
+            return ComparableTuple((self.content_type, self.content, self.encoding)) < \
+                ComparableTuple((other.content_type, other.content, other.encoding))
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash((self.content, self.content_type, self.encoding))
 
@@ -215,9 +260,9 @@ class AttachedText:
         return f'<AttachedText content-type={self.content_type}, encoding={self.encoding}>'
 
 
-class HashAlgorithm(Enum):
+class HashAlgorithm(str, Enum):
     """
-    This is out internal representation of the hashAlg simple type within the CycloneDX standard.
+    This is our internal representation of the hashAlg simple type within the CycloneDX standard.
 
     .. note::
         See the CycloneDX Schema: https://cyclonedx.org/docs/1.3/#type_hashAlg
@@ -320,6 +365,11 @@ class HashType:
             return hash(other) == hash(self)
         return False
 
+    def __lt__(self, other: Any) -> bool:
+        if isinstance(other, HashType):
+            return ComparableTuple((self.alg, self.content)) < ComparableTuple((other.alg, other.content))
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash((self.alg, self.content))
 
@@ -327,7 +377,7 @@ class HashType:
         return f'<HashType {self.alg.name}:{self.content}>'
 
 
-class ExternalReferenceType(Enum):
+class ExternalReferenceType(str, Enum):
     """
     Enum object that defines the permissible 'types' for an External Reference according to the CycloneDX schema.
 
@@ -378,6 +428,11 @@ class XsUri:
             return hash(other) == hash(self)
         return False
 
+    def __lt__(self, other: Any) -> bool:
+        if isinstance(other, XsUri):
+            return self._uri < other._uri
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash(self._uri)
 
@@ -390,7 +445,7 @@ class XsUri:
 
 class ExternalReference:
     """
-    This is out internal representation of an ExternalReference complex type that can be used in multiple places within
+    This is our internal representation of an ExternalReference complex type that can be used in multiple places within
     a CycloneDX BOM document.
 
     .. note::
@@ -402,7 +457,7 @@ class ExternalReference:
         self.url = url
         self.comment = comment
         self.type = reference_type
-        self.hashes = set(hashes or [])
+        self.hashes = SortedSet(hashes or [])
 
     @property
     def url(self) -> XsUri:
@@ -450,7 +505,7 @@ class ExternalReference:
         self._type = type_
 
     @property
-    def hashes(self) -> Set[HashType]:
+    def hashes(self) -> "SortedSet[HashType]":
         """
         The hashes of the external reference (if applicable).
 
@@ -461,13 +516,19 @@ class ExternalReference:
 
     @hashes.setter
     def hashes(self, hashes: Iterable[HashType]) -> None:
-        self._hashes = set(hashes)
+        self._hashes = SortedSet(hashes)
 
     def __eq__(self, other: object) -> bool:
         if isinstance(other, ExternalReference):
             return hash(other) == hash(self)
         return False
 
+    def __lt__(self, other: Any) -> bool:
+        if isinstance(other, ExternalReference):
+            return ComparableTuple((self._type, self._url, self._comment)) < \
+                ComparableTuple((other._type, other._url, other._comment))
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash((
             self._type, self._url, self._comment,
@@ -480,7 +541,7 @@ class ExternalReference:
 
 class License:
     """
-    This is out internal representation of `licenseType` complex type that can be used in multiple places within
+    This is our internal representation of `licenseType` complex type that can be used in multiple places within
     a CycloneDX BOM document.
 
     .. note::
@@ -566,6 +627,11 @@ class License:
             return hash(other) == hash(self)
         return False
 
+    def __lt__(self, other: Any) -> bool:
+        if isinstance(other, License):
+            return ComparableTuple((self.id, self.name)) < ComparableTuple((other.id, other.name))
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash((self.id, self.name, self.text, self.url))
 
@@ -575,7 +641,7 @@ class License:
 
 class LicenseChoice:
     """
-    This is out internal representation of `licenseChoiceType` complex type that can be used in multiple places within
+    This is our internal representation of `licenseChoiceType` complex type that can be used in multiple places within
     a CycloneDX BOM document.
 
     .. note::
@@ -633,6 +699,11 @@ class LicenseChoice:
             return hash(other) == hash(self)
         return False
 
+    def __lt__(self, other: Any) -> bool:
+        if isinstance(other, LicenseChoice):
+            return ComparableTuple((self.license, self.expression)) < ComparableTuple((other.license, other.expression))
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash((self.license, self.expression))
 
@@ -642,7 +713,7 @@ class LicenseChoice:
 
 class Property:
     """
-    This is out internal representation of `propertyType` complex type that can be used in multiple places within
+    This is our internal representation of `propertyType` complex type that can be used in multiple places within
     a CycloneDX BOM document.
 
     .. note::
@@ -690,6 +761,11 @@ class Property:
             return hash(other) == hash(self)
         return False
 
+    def __lt__(self, other: Any) -> bool:
+        if isinstance(other, Property):
+            return ComparableTuple((self.name, self.value)) < ComparableTuple((other.name, other.value))
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash((self.name, self.value))
 
@@ -699,7 +775,7 @@ class Property:
 
 class NoteText:
     """
-    This is out internal representation of the Note.text complex type that can be used in multiple places within
+    This is our internal representation of the Note.text complex type that can be used in multiple places within
     a CycloneDX BOM document.
 
     .. note::
@@ -763,6 +839,12 @@ class NoteText:
             return hash(other) == hash(self)
         return False
 
+    def __lt__(self, other: Any) -> bool:
+        if isinstance(other, NoteText):
+            return ComparableTuple((self.content, self.content_type, self.encoding)) < \
+                ComparableTuple((other.content, other.content_type, other.encoding))
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash((self.content, self.content_type, self.encoding))
 
@@ -772,7 +854,7 @@ class NoteText:
 
 class Note:
     """
-    This is out internal representation of the Note complex type that can be used in multiple places within
+    This is our internal representation of the Note complex type that can be used in multiple places within
     a CycloneDX BOM document.
 
     .. note::
@@ -830,6 +912,11 @@ class Note:
             return hash(other) == hash(self)
         return False
 
+    def __lt__(self, other: Any) -> bool:
+        if isinstance(other, Note):
+            return ComparableTuple((self.locale, self.text)) < ComparableTuple((other.locale, other.text))
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash((self.text, self.locale))
 
@@ -839,7 +926,7 @@ class Note:
 
 class OrganizationalContact:
     """
-    This is out internal representation of the `organizationalContact` complex type that can be used in multiple places
+    This is our internal representation of the `organizationalContact` complex type that can be used in multiple places
     within a CycloneDX BOM document.
 
     .. note::
@@ -902,16 +989,22 @@ class OrganizationalContact:
             return hash(other) == hash(self)
         return False
 
+    def __lt__(self, other: Any) -> bool:
+        if isinstance(other, OrganizationalContact):
+            return ComparableTuple((self.name, self.email, self.phone)) < \
+                ComparableTuple((other.name, other.email, other.phone))
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash((self.name, self.phone, self.email))
 
     def __repr__(self) -> str:
-        return f'<OrganizationalContact name={self.name}>'
+        return f'<OrganizationalContact name={self.name}, email={self.email}, phone={self.phone}>'
 
 
 class OrganizationalEntity:
     """
-    This is out internal representation of the `organizationalEntity` complex type that can be used in multiple places
+    This is our internal representation of the `organizationalEntity` complex type that can be used in multiple places
     within a CycloneDX BOM document.
 
     .. note::
@@ -925,8 +1018,8 @@ class OrganizationalEntity:
                 'One of name, urls or contacts must be supplied for an OrganizationalEntity - none supplied.'
             )
         self.name = name
-        self.url = set(urls or [])
-        self.contact = set(contacts or [])
+        self.url = SortedSet(urls or [])
+        self.contact = SortedSet(contacts or [])
 
     @property
     def name(self) -> Optional[str]:
@@ -943,7 +1036,7 @@ class OrganizationalEntity:
         self._name = name
 
     @property
-    def url(self) -> Set[XsUri]:
+    def url(self) -> "SortedSet[XsUri]":
         """
         Get a list of URLs of the organization. Multiple URLs are allowed.
 
@@ -954,10 +1047,10 @@ class OrganizationalEntity:
 
     @url.setter
     def url(self, urls: Iterable[XsUri]) -> None:
-        self._url = set(urls)
+        self._url = SortedSet(urls)
 
     @property
-    def contact(self) -> Set[OrganizationalContact]:
+    def contact(self) -> "SortedSet[OrganizationalContact]":
         """
         Get a list of contact person at the organization. Multiple contacts are allowed.
 
@@ -968,7 +1061,7 @@ class OrganizationalEntity:
 
     @contact.setter
     def contact(self, contacts: Iterable[OrganizationalContact]) -> None:
-        self._contact = set(contacts)
+        self._contact = SortedSet(contacts)
 
     def __eq__(self, other: object) -> bool:
         if isinstance(other, OrganizationalEntity):
@@ -984,7 +1077,7 @@ class OrganizationalEntity:
 
 class Tool:
     """
-    This is out internal representation of the `toolType` complex type within the CycloneDX standard.
+    This is our internal representation of the `toolType` complex type within the CycloneDX standard.
 
     Tool(s) are the things used in the creation of the BOM.
 
@@ -998,8 +1091,8 @@ class Tool:
         self.vendor = vendor
         self.name = name
         self.version = version
-        self.hashes = set(hashes or [])
-        self.external_references = set(external_references or [])
+        self.hashes = SortedSet(hashes or [])
+        self.external_references = SortedSet(external_references or [])
 
     @property
     def vendor(self) -> Optional[str]:
@@ -1044,7 +1137,7 @@ class Tool:
         self._version = version
 
     @property
-    def hashes(self) -> Set[HashType]:
+    def hashes(self) -> "SortedSet[HashType]":
         """
         The hashes of the tool (if applicable).
 
@@ -1055,10 +1148,10 @@ class Tool:
 
     @hashes.setter
     def hashes(self, hashes: Iterable[HashType]) -> None:
-        self._hashes = set(hashes)
+        self._hashes = SortedSet(hashes)
 
     @property
-    def external_references(self) -> Set[ExternalReference]:
+    def external_references(self) -> "SortedSet[ExternalReference]":
         """
         External References provide a way to document systems, sites, and information that may be relevant but which
         are not included with the BOM.
@@ -1070,13 +1163,19 @@ class Tool:
 
     @external_references.setter
     def external_references(self, external_references: Iterable[ExternalReference]) -> None:
-        self._external_references = set(external_references)
+        self._external_references = SortedSet(external_references)
 
     def __eq__(self, other: object) -> bool:
         if isinstance(other, Tool):
             return hash(other) == hash(self)
         return False
 
+    def __lt__(self, other: Any) -> bool:
+        if isinstance(other, Tool):
+            return ComparableTuple((self.vendor, self.name, self.version)) < \
+                ComparableTuple((other.vendor, other.name, other.version))
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash((self.vendor, self.name, self.version, tuple(self.hashes), tuple(self.external_references)))
 
@@ -1086,7 +1185,7 @@ class Tool:
 
 class IdentifiableAction:
     """
-    This is out internal representation of the `identifiableActionType` complex type.
+    This is our internal representation of the `identifiableActionType` complex type.
 
     .. note::
         See the CycloneDX specification: https://cyclonedx.org/docs/1.4/xml/#type_identifiableActionType
@@ -1150,6 +1249,12 @@ class IdentifiableAction:
             return hash(other) == hash(self)
         return False
 
+    def __lt__(self, other: Any) -> bool:
+        if isinstance(other, IdentifiableAction):
+            return ComparableTuple((self.timestamp, self.name, self.email)) < \
+                ComparableTuple((other.timestamp, other.name, other.email))
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash((self.timestamp, self.name, self.email))
 
@@ -1159,7 +1264,7 @@ class IdentifiableAction:
 
 class Copyright:
     """
-    This is out internal representation of the `copyrightsType` complex type.
+    This is our internal representation of the `copyrightsType` complex type.
 
     .. note::
         See the CycloneDX specification: https://cyclonedx.org/docs/1.4/xml/#type_copyrightsType
@@ -1187,6 +1292,11 @@ class Copyright:
             return hash(other) == hash(self)
         return False
 
+    def __lt__(self, other: Any) -> bool:
+        if isinstance(other, Copyright):
+            return self.text < other.text
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash(self.text)
 
