@@ -14,16 +14,19 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 # Copyright (c) OWASP Foundation. All Rights Reserved.
+
 from enum import Enum
-from typing import Iterable, Optional, Set
+from typing import Any, Iterable, Optional
+
+from sortedcontainers import SortedSet
 
-from . import XsUri
 from ..exception.model import NoPropertiesProvidedException
+from . import ComparableTuple, XsUri
 
 
-class IssueClassification(Enum):
+class IssueClassification(str, Enum):
     """
-    This is out internal representation of the enum `issueClassification`.
+    This is our internal representation of the enum `issueClassification`.
 
     .. note::
         See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.4/xml/#type_issueClassification
@@ -35,7 +38,7 @@ class IssueClassification(Enum):
 
 class IssueTypeSource:
     """
-    This is out internal representation ofa source within the IssueType complex type that can be used in multiple
+    This is our internal representation ofa source within the IssueType complex type that can be used in multiple
     places within a CycloneDX BOM document.
 
     .. note::
@@ -83,6 +86,11 @@ class IssueTypeSource:
             return hash(other) == hash(self)
         return False
 
+    def __lt__(self, other: Any) -> bool:
+        if isinstance(other, IssueTypeSource):
+            return ComparableTuple((self.name, self.url)) < ComparableTuple((other.name, other.url))
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash((self.name, self.url))
 
@@ -92,7 +100,7 @@ class IssueTypeSource:
 
 class IssueType:
     """
-    This is out internal representation of an IssueType complex type that can be used in multiple places within
+    This is our internal representation of an IssueType complex type that can be used in multiple places within
     a CycloneDX BOM document.
 
     .. note::
@@ -107,7 +115,7 @@ class IssueType:
         self.name = name
         self.description = description
         self.source = source
-        self.references = set(references or [])
+        self.references = SortedSet(references or [])
 
     @property
     def type(self) -> IssueClassification:
@@ -180,7 +188,7 @@ class IssueType:
         self._source = source
 
     @property
-    def references(self) -> Set[XsUri]:
+    def references(self) -> "SortedSet[XsUri]":
         """
         Any reference URLs related to this issue.
 
@@ -191,13 +199,19 @@ class IssueType:
 
     @references.setter
     def references(self, references: Iterable[XsUri]) -> None:
-        self._references = set(references)
+        self._references = SortedSet(references)
 
     def __eq__(self, other: object) -> bool:
         if isinstance(other, IssueType):
             return hash(other) == hash(self)
         return False
 
+    def __lt__(self, other: Any) -> bool:
+        if isinstance(other, IssueType):
+            return ComparableTuple((self.type, self.id, self.name, self.description, self.source)) < \
+                ComparableTuple((other.type, other.id, other.name, other.description, other.source))
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash((
             self.type, self.id, self.name, self.description, self.source, tuple(self.references)
