@@ -18,7 +18,9 @@
 # Copyright (c) OWASP Foundation. All Rights Reserved.
 
 from datetime import datetime
-from typing import Iterable, Optional, Set
+from typing import Iterable, Optional
+
+from sortedcontainers import SortedSet
 
 from ..model import Note, Property, XsUri
 from ..model.issue import IssueType
@@ -43,11 +45,11 @@ class ReleaseNotes:
         self.social_image = social_image
         self.description = description
         self.timestamp = timestamp
-        self.aliases = set(aliases or [])
-        self.tags = set(tags or [])
-        self.resolves = set(resolves or [])
-        self.notes = set(notes or [])
-        self.properties = set(properties or [])
+        self.aliases = SortedSet(aliases or [])
+        self.tags = SortedSet(tags or [])
+        self.resolves = SortedSet(resolves or [])
+        self.notes = SortedSet(notes or [])
+        self.properties = SortedSet(properties or [])
 
     @property
     def type(self) -> str:
@@ -130,7 +132,7 @@ class ReleaseNotes:
         self._timestamp = timestamp
 
     @property
-    def aliases(self) -> Set[str]:
+    def aliases(self) -> "SortedSet[str]":
         """
         One or more alternate names the release may be referred to. This may include unofficial terms used by
         development and marketing teams (e.g. code names).
@@ -142,10 +144,10 @@ class ReleaseNotes:
 
     @aliases.setter
     def aliases(self, aliases: Iterable[str]) -> None:
-        self._aliases = set(aliases)
+        self._aliases = SortedSet(aliases)
 
     @property
-    def tags(self) -> Set[str]:
+    def tags(self) -> "SortedSet[str]":
         """
         One or more tags that may aid in search or retrieval of the release note.
 
@@ -156,10 +158,10 @@ class ReleaseNotes:
 
     @tags.setter
     def tags(self, tags: Iterable[str]) -> None:
-        self._tags = set(tags)
+        self._tags = SortedSet(tags)
 
     @property
-    def resolves(self) -> Set[IssueType]:
+    def resolves(self) -> "SortedSet[IssueType]":
         """
         A collection of issues that have been resolved.
 
@@ -170,10 +172,10 @@ class ReleaseNotes:
 
     @resolves.setter
     def resolves(self, resolves: Iterable[IssueType]) -> None:
-        self._resolves = set(resolves)
+        self._resolves = SortedSet(resolves)
 
     @property
-    def notes(self) -> Set[Note]:
+    def notes(self) -> "SortedSet[Note]":
         """
         Zero or more release notes containing the locale and content. Multiple note elements may be specified to support
         release notes in a wide variety of languages.
@@ -185,10 +187,10 @@ class ReleaseNotes:
 
     @notes.setter
     def notes(self, notes: Iterable[Note]) -> None:
-        self._notes = set(notes)
+        self._notes = SortedSet(notes)
 
     @property
-    def properties(self) -> Set[Property]:
+    def properties(self) -> "SortedSet[Property]":
         """
         Provides the ability to document properties in a name-value store. This provides flexibility to include data not
         officially supported in the standard without having to use additional namespaces or create extensions. Unlike
@@ -201,7 +203,7 @@ class ReleaseNotes:
 
     @properties.setter
     def properties(self, properties: Iterable[Property]) -> None:
-        self._properties = set(properties)
+        self._properties = SortedSet(properties)
 
     def __eq__(self, other: object) -> bool:
         if isinstance(other, ReleaseNotes):
